from setuptools import setup, find_packages

setup(
    name="pyeztrace",
    version="0.0.13",
    description="Python tracing and logging library",
    author="Jefferson Nelsson",
    packages=find_packages(),
    install_requires=[],
    python_requires=">=3.7",
)
